.. :changelog:

History
-------

1.3.1 (2014-03-07)
++++++++++++++++++

* Fix HISTORY.rst
* Remove Python 2.6 from Travis configuration

1.3.0 (2014-03-06)
++++++++++++++++++

* Improved (cookiecutter-pypackage style) project layout

1.2.0 (2014-01-14)
++++++++++++++++++

* Specify an environment variable as required, and raise ImproperlyConfigured 
  exception if not present (#2)

1.1.0 (2013-07-24)
++++++++++++++++++

* Marked as "5 - Production/Stable" instead of "4 - Beta"
* Cleaned up README
* Added CHANGES

1.0.0 (2013-07-19)
++++++++++++++++++

* Initial release
